@@ -1,10 +1,10 @@
 import os
 from multiprocessing import Process
-from typing import Dict, Type
+from typing import Dict, Optional, Type, Union
 
+import fsspec
 import psutil
 from jupyter_core.paths import jupyter_data_dir
-from jupyter_server.traittypes import TypeFromClasses
 from jupyter_server.transutils import _i18n
 from jupyter_server.utils import to_os_path
 from sqlalchemy import and_, asc, desc, func
@@ -21,11 +21,11 @@ from jupyter_scheduler.models import (
     CreateJobDefinition,
     DescribeJob,
     DescribeJobDefinition,
+    JobFile,
     ListJobDefinitionsQuery,
     ListJobDefinitionsResponse,
     ListJobsQuery,
     ListJobsResponse,
-    Output,
     SortDirection,
     Status,
     UpdateJob,
@@ -44,13 +44,25 @@ class BaseScheduler(LoggingConfigurable):
     """
 
     staging_path = Unicode(
+        config=True,
         help=_i18n(
             """Full path to staging location, where output
         files will be stored after job execution completes. This
         could be a local or remote path including cloud storage.
         Default value is jupyter data directory.
         """
-        )
+        ),
+    )
+
+    output_directory = Unicode(
+        default_value="jobs",
+        config=True,
+        help=_i18n(
+            """Local path to the directory where job files
+        will be downloaded. This directory will host sub-directories
+        for each new job.
+        """
+        ),
     )
 
     @default("staging_path")
@@ -101,8 +113,19 @@ class BaseScheduler(LoggingConfigurable):
         """Returns number of jobs filtered by query"""
         raise NotImplementedError("must be implemented by subclass")
 
-    def get_job(self, job_id: str) -> DescribeJob:
-        """Returns job record for a single job"""
+    def get_job(self, job_id: str, job_files: Optional[bool] = True) -> DescribeJob:
+        """Returns job record for a single job.
+
+        Parameters
+        ----------
+        job_id : str
+            Unique identifier for the job
+
+        job_files : bool, optional
+            If True, checks for job files in local path
+            and populates the job_files property. When
+            False, `add_job_files` should not be called.
+        """
         raise NotImplementedError("must be implemented by subclass")
 
     def delete_job(self, job_id: str):
@@ -116,6 +139,7 @@ class BaseScheduler(LoggingConfigurable):
         API with status update to STOPPED, which will
         call the stop_job method.
         """
+
         raise NotImplementedError("must be implemented by subclass")
 
     def create_job_definition(self, model: CreateJobDefinition) -> str:
@@ -145,8 +169,50 @@ class BaseScheduler(LoggingConfigurable):
         """Returns list of all job definitions filtered by query"""
         raise NotImplementedError("must be implemented by subclass")
 
-    def get_staging_paths(self, job_id: str) -> Dict[str, str]:
-        """Returns full staging paths for all job outputs"""
+    def get_staging_paths(self, model: Union[DescribeJob, DescribeJobDefinition]) -> Dict[str, str]:
+        """Returns full staging paths for all job files
+
+        Notes
+        -----
+        Any path supported by `fsspec https://filesystem-spec.readthedocs.io/en/latest/index.html`_
+        is a valid return value. For staging files that
+        are stored as tar or compressed tar archives, this
+        should specify the first entry with a key as `tar`
+        or `tar.gz` and value as path to the archive file;
+        the values for the actual format files will be just
+        the path to them in the archive, in most cases just
+        the filename. For input files, the key 'input' is
+        expected.
+
+
+        Examples
+        --------
+        >>> self.get_staging_paths(1)
+        {
+            'ipynb': '/job_files/helloworld-2022-10-10.ipynb',
+            'html': '/job_files/helloworld-2022-10-10.html',
+            'input': '/job_files/helloworld.ipynb'
+        }
+
+        For files that are archived as tar or compressed tar
+        >>> self.get_staging_paths(2)
+        {
+            'tar.gz': '/job_files/helloworld.tar.gz',
+            'ipynb': 'helloworld-2022-10-10.ipynb',
+            'html': 'helloworld-2022-10-10.html',
+            'input': 'helloworld.ipynb'
+        }
+
+        Parameters
+        ----------
+        job_id : str
+            Unique identifier for the job
+
+        Returns
+        -------
+        Dictionary with keys as output format and values
+        as full path to the job file in staging location.
+        """
         raise NotImplementedError("must be implemented by subclass")
 
     def file_exists(self, path: str):
@@ -171,27 +237,81 @@ class BaseScheduler(LoggingConfigurable):
         else:
             return os.path.isfile(os_path)
 
-    def add_outputs(self, model: DescribeJob):
-        """Adds outputs to the model, ensures output
-        files are present in the local workspace. These
-        should be added in `get_job` and `list_job` APIs
-        once the rest of the model is populated.
+    def get_job_filenames(self, model: DescribeJob) -> Dict[str, str]:
+        """Returns dictionary mapping output formats to
+        the job filenames in the JupyterLab workspace.
+
+        Notes
+        -----
+        This should be called by both `add_job_files` and
+        `JobFilesManager` to ensure that job output and
+        input files are written to the expected filepaths.
+        For input files, the key `input` is expected.
+
+        Examples
+        --------
+        >>> self.get_job_filenames(model)
+        {
+            'ipynb': 'helloworld-2022-10-10.ipynb',
+            'html': 'helloworld-2022-10-10.html',
+            'input': 'helloworld.ipynb'
+        }
+
+        """
+
+        filenames = {}
+        for output_format in model.output_formats:
+            filenames[output_format] = create_output_filename(
+                model.input_filename, model.create_time, output_format
+            )
+
+        filenames["input"] = model.input_filename
+
+        return filenames
+
+    def add_job_files(self, model: DescribeJob):
+        """Adds `job_files` to the model, ensures job files
+        are present in the local workspace. These should be
+        added in `get_job` and `list_job` APIs once the rest
+        of the model is populated.
         """
         mapping = self.environments_manager.output_formats_mapping()
-        outputs = []
+        job_files = []
+        output_filenames = self.get_job_filenames(model)
+        output_dir = os.path.relpath(self.get_local_output_path(model), self.root_dir)
         for output_format in model.output_formats:
-            filename = create_output_filename(model.input_uri, model.create_time, output_format)
-            output_path = os.path.join(model.output_prefix, filename)
-            outputs.append(
-                Output(
+            filename = output_filenames[output_format]
+            output_path = os.path.join(output_dir, filename)
+            job_files.append(
+                JobFile(
                     display_name=mapping[output_format],
-                    output_format=output_format,
-                    output_path=output_path if self.file_exists(output_path) else None,
+                    file_format=output_format,
+                    file_path=output_path if self.file_exists(output_path) else None,
                 )
             )
 
-        model.outputs = outputs
-        model.downloaded = all(output.output_path for output in outputs)
+        # Add input file
+        filename = model.input_filename
+        format = "input"
+        output_path = os.path.join(output_dir, filename)
+        job_files.append(
+            JobFile(
+                display_name="Input",
+                file_format=format,
+                file_path=output_path if self.file_exists(output_path) else None,
+            )
+        )
+
+        model.job_files = job_files
+        model.downloaded = all(job_file.file_path for job_file in job_files)
+
+    def get_local_output_path(self, model: DescribeJob) -> str:
+        """Returns the local output directory path
+        where all the job files will be downloaded
+        from the staging location.
+        """
+        output_dir_name = create_output_filename(model.input_filename, model.create_time)
+        return os.path.join(self.root_dir, self.output_directory, output_dir_name)
 
 
 class Scheduler(BaseScheduler):
@@ -233,11 +353,18 @@ class Scheduler(BaseScheduler):
 
         return self._db_session
 
-    def create_job(self, model: CreateJob) -> str:
-        with self.db_session() as session:
-            if not self.file_exists(model.input_uri):
-                raise InputUriError(model.input_uri)
+    def copy_input_file(self, input_uri: str, copy_to_path: str):
+        """Copies the input file to the staging directory"""
+        input_filepath = os.path.join(self.root_dir, input_uri)
+        with fsspec.open(input_filepath) as input_file:
+            with fsspec.open(copy_to_path, "wb") as output_file:
+                output_file.write(input_file.read())
 
+    def create_job(self, model: CreateJob) -> str:
+        if not model.job_definition_id and not self.file_exists(model.input_uri):
+            raise InputUriError(model.input_uri)
+
+        with self.db_session() as session:
             if model.idempotency_token:
                 job = (
                     session.query(Job)
@@ -248,13 +375,14 @@ class Scheduler(BaseScheduler):
                     raise IdempotencyTokenError(model.idempotency_token)
 
             if not model.output_formats:
-                model.output_formats = ["ipynb"]
+                model.output_formats = []
 
-            job = Job(**model.dict(exclude_none=True))
+            job = Job(**model.dict(exclude_none=True, exclude={"input_uri"}))
             session.add(job)
             session.commit()
 
-            staging_paths = self.get_staging_paths(job.job_id)
+            staging_paths = self.get_staging_paths(DescribeJob.from_orm(job))
+            self.copy_input_file(model.input_uri, staging_paths["input"])
 
             p = Process(
                 target=self.execution_manager_class(
@@ -311,7 +439,7 @@ class Scheduler(BaseScheduler):
         jobs_list = []
         for job in jobs:
             model = DescribeJob.from_orm(job)
-            self.add_outputs(model=model)
+            self.add_job_files(model=model)
             jobs_list.append(model)
 
         list_jobs_response = ListJobsResponse(
@@ -329,12 +457,13 @@ class Scheduler(BaseScheduler):
             )
             return count if count else 0
 
-    def get_job(self, job_id: str) -> DescribeJob:
+    def get_job(self, job_id: str, job_files: Optional[bool] = True) -> DescribeJob:
         with self.db_session() as session:
             job_record = session.query(Job).filter(Job.job_id == job_id).one()
 
         model = DescribeJob.from_orm(job_record)
-        self.add_outputs(model=model)
+        if job_files:
+            self.add_job_files(model=model)
 
         return model
 
@@ -372,12 +501,15 @@ class Scheduler(BaseScheduler):
             if not self.file_exists(model.input_uri):
                 raise InputUriError(model.input_uri)
 
-            job_definition = JobDefinition(**model.dict(exclude_none=True))
+            job_definition = JobDefinition(**model.dict(exclude_none=True, exclude={"input_uri"}))
             session.add(job_definition)
             session.commit()
 
             job_definition_id = job_definition.job_definition_id
 
+            staging_paths = self.get_staging_paths(DescribeJobDefinition.from_orm(job_definition))
+            self.copy_input_file(model.input_uri, staging_paths["input"])
+
         if self.task_runner and job_definition.schedule:
             self.task_runner.add_job_definition(job_definition_id)
 
@@ -469,13 +601,49 @@ class Scheduler(BaseScheduler):
 
         return list_response
 
-    def get_staging_paths(self, job_id: str) -> Dict[str, str]:
-        model = self.get_job(job_id)
+    def get_staging_paths(self, model: Union[DescribeJob, DescribeJobDefinition]) -> Dict[str, str]:
         staging_paths = {}
-        for output in model.outputs:
+        if not model:
+            return staging_paths
+
+        id = model.job_id if isinstance(model, DescribeJob) else model.job_definition_id
+
+        for output_format in model.output_formats:
             filename = create_output_filename(
-                model.input_uri, model.create_time, output.output_format
+                model.input_filename, model.create_time, output_format
             )
-            staging_paths[output.output_format] = os.path.join(self.staging_path, job_id, filename)
+            staging_paths[output_format] = os.path.join(self.staging_path, id, filename)
+
+        staging_paths["input"] = os.path.join(self.staging_path, id, model.input_filename)
+
+        return staging_paths
+
+
+class ArchivingScheduler(Scheduler):
+    """Scheduler that adds archive path to staging paths."""
+
+    execution_manager_class = TType(
+        klass="jupyter_scheduler.executors.ExecutionManager",
+        default_value="jupyter_scheduler.executors.ArchivingExecutionManager",
+        config=True,
+    )
+
+    def get_staging_paths(self, model: Union[DescribeJob, DescribeJobDefinition]) -> Dict[str, str]:
+        staging_paths = {}
+        if not model:
+            return staging_paths
+
+        id = model.job_id if isinstance(model, DescribeJob) else model.job_definition_id
+
+        for output_format in model.output_formats:
+            filename = create_output_filename(
+                model.input_filename, model.create_time, output_format
+            )
+            staging_paths[output_format] = filename
+
+        output_format = "tar.gz"
+        filename = create_output_filename(model.input_filename, model.create_time, output_format)
+        staging_paths[output_format] = os.path.join(self.staging_path, model.job_id, filename)
+        staging_paths["input"] = os.path.join(self.staging_path, model.job_id, model.input_filename)
 
         return staging_paths
