@@ -1,14 +1,17 @@
-import React, { useEffect, useState } from 'react';
+import React, { useCallback, useEffect, useState } from 'react';
 
 import { useTheme } from '@mui/material/styles';
 import Table from '@mui/material/Table';
 import TableContainer from '@mui/material/TableContainer';
 import TableBody from '@mui/material/TableBody';
-import TablePagination from '@mui/material/TablePagination';
+import TablePagination, {
+  LabelDisplayedRowsArgs
+} from '@mui/material/TablePagination';
 import Paper from '@mui/material/Paper';
 
 import { Scheduler } from '../../handler';
 import { AdvancedTableHeader } from './advanced-table-header';
+import { useTranslator } from '../../hooks';
 
 const PAGE_SIZE = 25;
 
@@ -20,7 +23,7 @@ export type AdvancedTableColumn = {
 type AdvancedTablePayload =
   | {
       next_token?: string;
-      total_count: number;
+      total_count?: number;
     }
   | undefined;
 
@@ -69,10 +72,11 @@ export function AdvancedTable<
 >(props: AdvancedTableProps<P, Q, R>): JSX.Element {
   const [rows, setRows] = useState<R[]>();
   const [nextToken, setNextToken] = useState<string>();
-  const [totalCount, setTotalCount] = useState<number>(0);
+  const [totalCount, setTotalCount] = useState<number>();
   const [page, setPage] = useState<number>(0);
   const [maxPage, setMaxPage] = useState<number>(0);
   const [loading, setLoading] = useState<boolean>(true);
+  const trans = useTranslator('jupyterlab');
   const theme = useTheme();
 
   const pageSize = props.pageSize ?? PAGE_SIZE;
@@ -153,8 +157,35 @@ export function AdvancedTable<
     setMaxPage(newPage);
   };
 
+  const onLastPage = page === maxPage && nextToken === undefined;
+
   const height = props.height ?? 'auto';
 
+  /**
+   * Renders the label to the left of the pagination buttons.
+   */
+  const labelDisplayedRows = useCallback(
+    ({ from, to, count }: LabelDisplayedRowsArgs) => {
+      if (count === -1) {
+        const loadedRows = rows?.length ?? 0;
+        if (onLastPage) {
+          // for some reason `to` is set incorrectly on the last page in
+          // server-side pagination, so we need to build the string differently
+          // in this case.
+          return trans.__('%1–%2 of %3', from, loadedRows, loadedRows);
+        } else {
+          return (
+            trans.__('%1–%2 of %3', from, to,
+              loadedRows + (nextToken === undefined ? '' : '+'))
+          );
+        }
+      } else {
+        return trans.__('%1–%2 of %3', from, to, count);
+      }
+    },
+    [rows, onLastPage, trans]
+  );
+
   return (
     <div
       style={height === 'auto' ? { flex: 1, height: 0 } : { maxHeight: height }}
@@ -182,11 +213,12 @@ export function AdvancedTable<
             backgroundColor: theme.palette.background.paper,
             borderTop: `1px solid ${theme.palette.divider}`
           }}
-          count={totalCount}
+          count={totalCount ?? -1}
+          labelDisplayedRows={labelDisplayedRows}
           page={page}
           onPageChange={handlePageChange}
           nextIconButtonProps={{
-            disabled: page === maxPage && !nextToken
+            disabled: onLastPage
           }}
           rowsPerPage={pageSize}
           rowsPerPageOptions={[pageSize]}
