@@ -1,30 +1,17 @@
-import React from 'react';
 import {
   ILayoutRestorer,
   JupyterFrontEnd,
   JupyterFrontEndPlugin
 } from '@jupyterlab/application';
-import {
-  MainAreaWidget,
-  ReactWidget,
-  WidgetTracker
-} from '@jupyterlab/apputils';
+import { MainAreaWidget, WidgetTracker } from '@jupyterlab/apputils';
 import { FileBrowser, IFileBrowserFactory } from '@jupyterlab/filebrowser';
 import { ILauncher } from '@jupyterlab/launcher';
 import { INotebookTracker } from '@jupyterlab/notebook';
 import { Contents } from '@jupyterlab/services';
-import { IStatusBar } from '@jupyterlab/statusbar';
 import { ITranslator } from '@jupyterlab/translation';
 
-import { Poll } from '@lumino/polling';
-import { RunningJobsIndicator } from './components/running-jobs-indicator';
-
 import { SchedulerService } from './handler';
-import {
-  NotebookJobsListingModel,
-  IJobsModel,
-  emptyCreateJobModel
-} from './model';
+import { IJobsModel, emptyCreateJobModel } from './model';
 import { NotebookJobsPanel } from './notebook-jobs-panel';
 import {
   calendarAddOnIcon,
@@ -40,7 +27,7 @@ export namespace CommandIDs {
   export const createJobCurrentNotebook = 'scheduling:create-from-notebook';
   export const showNotebookJobs = 'scheduling:show-notebook-jobs';
   export const stopJob = 'scheduling:stop-job';
-  export const downloadOutputs = 'scheduling:download-outputs';
+  export const downloadFiles = 'scheduling:download-files';
 }
 
 export const NotebookJobsPanelId = 'notebook-jobs-panel';
@@ -58,7 +45,7 @@ const schedulerPlugin: JupyterFrontEndPlugin<void> = {
     ILayoutRestorer,
     Scheduler.IAdvancedOptions
   ],
-  optional: [IStatusBar, ILauncher],
+  optional: [ILauncher],
   autoStart: true,
   activate: activatePlugin
 };
@@ -87,14 +74,7 @@ function getSelectedItem(widget: FileBrowser | null): Contents.IModel | null {
   return firstItem;
 }
 
-function getSelectedFilePath(widget: FileBrowser | null): string | null {
-  const selectedItem = getSelectedItem(widget);
-  if (selectedItem === null) {
-    return null;
-  }
-  return selectedItem.path;
-}
-
+// Get only the file name, with no parent directories, of the currently selected file.
 function getSelectedFileName(widget: FileBrowser | null): string | null {
   const selectedItem = getSelectedItem(widget);
   if (selectedItem === null) {
@@ -103,18 +83,26 @@ function getSelectedFileName(widget: FileBrowser | null): string | null {
   return selectedItem.name;
 }
 
-let scheduledJobsListingModel: NotebookJobsListingModel | null = null;
+// Get the file name, with all parent directories, of the currently selected file.
+function getSelectedFilePath(widget: FileBrowser | null): string | null {
+  const selectedItem = getSelectedItem(widget);
+  if (selectedItem === null) {
+    return null;
+  }
+  return selectedItem.path;
+}
 
-async function getNotebookJobsListingModel(): Promise<NotebookJobsListingModel> {
-  if (scheduledJobsListingModel) {
-    return scheduledJobsListingModel;
+// Get the containing directory of the file at a particular path.
+function getDirectoryFromPath(path: string | null): string | null {
+  if (path === null) {
+    return null;
   }
 
-  const api = new SchedulerService({});
-
-  const jobsResponse = await api.getJobs({});
-  scheduledJobsListingModel = new NotebookJobsListingModel(jobsResponse.jobs);
-  return scheduledJobsListingModel;
+  // Remove the final portion of the path, the filename.
+  const directories = path.split('/');
+  directories.pop();
+  // Include a trailing slash only if there is at least one subdirectory.
+  return directories.join('/') + (directories.length > 0 ? '/' : '');
 }
 
 async function activatePlugin(
@@ -124,14 +112,8 @@ async function activatePlugin(
   translator: ITranslator,
   restorer: ILayoutRestorer,
   advancedOptions: Scheduler.IAdvancedOptions,
-  statusBar: IStatusBar | null,
   launcher: ILauncher | null
 ): Promise<void> {
-  // first, validate presence of dependencies
-  if (!statusBar) {
-    return;
-  }
-
   const { commands } = app;
   const trans = translator.load('jupyterlab');
   const fileBrowserTracker = browserFactory.tracker;
@@ -197,12 +179,12 @@ async function activatePlugin(
     execute: async () => {
       const widget = fileBrowserTracker.currentWidget;
       const filePath = getSelectedFilePath(widget) ?? '';
-      const fileName = getSelectedFileName(widget) ?? '';
 
       // Update the job form inside the notebook jobs widget
       const newCreateModel = emptyCreateJobModel();
       newCreateModel.inputFile = filePath;
-      newCreateModel.jobName = fileName;
+      newCreateModel.jobName = getSelectedFileName(widget) ?? '';
+      newCreateModel.outputPath = getDirectoryFromPath(filePath) ?? '';
 
       await showJobsPanel({
         jobsView: 'CreateJob',
@@ -225,6 +207,7 @@ async function activatePlugin(
       const newCreateModel = emptyCreateJobModel();
       newCreateModel.inputFile = filePath;
       newCreateModel.jobName = fileName;
+      newCreateModel.outputPath = getDirectoryFromPath(filePath) ?? '';
 
       await showJobsPanel({
         jobsView: 'CreateJob',
@@ -253,44 +236,14 @@ async function activatePlugin(
     label: trans.__('Stop Job')
   });
 
-  commands.addCommand(CommandIDs.downloadOutputs, {
+  commands.addCommand(CommandIDs.downloadFiles, {
     execute: async args => {
       const id = args['id'] as string;
       const redownload = args['redownload'] as boolean;
-      await api.downloadOutputs(id, redownload);
+      await api.downloadFiles(id, redownload);
     }
   });
 
-  // validate presence of status bar
-  if (!statusBar) {
-    return;
-  }
-
-  const scheduledJobsListingModel = await getNotebookJobsListingModel();
-  statusBar.registerStatusItem('jupyterlab-scheduler:status', {
-    align: 'middle',
-    item: ReactWidget.create(
-      <RunningJobsIndicator
-        onClick={async () => showJobsPanel({ jobsView: 'ListJobs' })}
-        model={scheduledJobsListingModel}
-      />
-    )
-  });
-
-  const statusPoll = new Poll({
-    factory: async () => {
-      const model = jobsPanel?.model;
-      if (!model) {
-        return;
-      }
-
-      const jobCount = await api.getjobCount('IN_PROGRESS');
-      model.jobCount = jobCount;
-    },
-    frequency: { interval: 1000, backoff: false }
-  });
-  statusPoll.start();
-
   // Add to launcher
   if (launcher) {
     launcher.add({
