@@ -16,20 +16,23 @@ import { ICreateJobModel, IJobParameter, ListJobsView } from '../model';
 import { Scheduler as SchedulerTokens } from '../tokens';
 
 import ErrorIcon from '@mui/icons-material/Error';
+import FolderIcon from '@mui/icons-material/Folder';
 
-import Alert from '@mui/material/Alert';
-import Button from '@mui/material/Button';
-import Box from '@mui/system/Box';
-import Stack from '@mui/system/Stack';
-import TextField from '@mui/material/TextField';
 import {
   Accordion,
   AccordionDetails,
   AccordionSummary,
+  Alert,
+  Button,
+  CircularProgress,
   FormLabel,
-  SelectChangeEvent
+  InputAdornment,
+  SelectChangeEvent,
+  TextField
 } from '@mui/material';
 
+import { Box, Stack } from '@mui/system';
+
 import { caretDownIcon } from '@jupyterlab/ui-components';
 
 import cronstrue from 'cronstrue';
@@ -86,9 +89,28 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
       const envList = await api.getRuntimeEnvironments();
       setEnvironmentList(envList);
       if (envList.length === 1) {
+        // If no default compute type is specified, show the first one by default
+        let newComputeType = envList[0].compute_types?.[0];
+
+        // Validate that the default compute type is in fact in the list
+        if (
+          envList[0].default_compute_type &&
+          envList[0].compute_types &&
+          envList[0].compute_types.includes(envList[0].default_compute_type)
+        ) {
+          newComputeType = envList[0].default_compute_type;
+        }
+
+        const outputFormats = outputFormatsForEnvironment(
+          envList,
+          envList[0].name
+        )?.map(format => format.name);
+
         props.handleModelChange({
           ...props.model,
-          environment: envList[0].name
+          environment: envList[0].name,
+          computeType: newComputeType,
+          outputFormats: outputFormats
         });
       }
     };
@@ -156,13 +178,27 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
   const handleSelectChange = (event: SelectChangeEvent<string>) => {
     const target = event.target;
 
-    // if setting the environment, default the compute type to its first value (if any are presnt)
+    // if setting the environment, default the compute type to its default value or its first value
     if (target.name === 'environment') {
       const envObj = environmentList.find(env => env.name === target.value);
+      // Validate that the default compute type is in fact in the list
+      let newComputeType = envObj?.compute_types?.[0];
+      if (
+        envObj?.default_compute_type &&
+        envObj?.compute_types &&
+        envObj?.compute_types.includes(envObj?.default_compute_type)
+      ) {
+        newComputeType = envObj.default_compute_type;
+      }
+      const newEnvOutputFormats = outputFormatsForEnvironment(
+        environmentList,
+        target.value
+      )?.map(format => format.name);
       props.handleModelChange({
         ...props.model,
         environment: target.value,
-        computeType: envObj?.compute_types?.[0]
+        computeType: newComputeType,
+        outputFormats: newEnvOutputFormats
       });
     } else {
       // otherwise, just set the model
@@ -574,7 +610,6 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
     const jobOptions: Scheduler.ICreateJob = {
       name: props.model.jobName,
       input_uri: props.model.inputFile,
-      output_prefix: props.model.outputPath,
       runtime_environment_name: props.model.environment,
       output_formats: props.model.outputFormats,
       compute_type: props.model.computeType,
@@ -587,7 +622,11 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
       jobOptions.parameters = serializeParameters(props.model.parameters);
     }
 
-    props.handleModelChange({ ...props.model, createError: undefined });
+    props.handleModelChange({
+      ...props.model,
+      createError: undefined,
+      createInProgress: true
+    });
 
     api
       .createJob(jobOptions)
@@ -595,8 +634,12 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
         // Switch to the list view with "Job List" active
         props.showListView('Job');
       })
-      .catch((error: string) => {
-        props.handleModelChange({ ...props.model, createError: error });
+      .catch((error: Error) => {
+        props.handleModelChange({
+          ...props.model,
+          createError: error.message,
+          createInProgress: false
+        });
       });
   };
 
@@ -611,7 +654,6 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
     const jobDefinitionOptions: Scheduler.ICreateJobDefinition = {
       name: props.model.jobName,
       input_uri: props.model.inputFile,
-      output_prefix: props.model.outputPath,
       runtime_environment_name: props.model.environment,
       compute_type: props.model.computeType,
       output_formats: props.model.outputFormats,
@@ -627,7 +669,11 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
       );
     }
 
-    props.handleModelChange({ ...props.model, createError: undefined });
+    props.handleModelChange({
+      ...props.model,
+      createError: undefined,
+      createInProgress: true
+    });
 
     api
       .createJobDefinition(jobDefinitionOptions)
@@ -636,7 +682,11 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
         props.showListView('JobDefinition');
       })
       .catch((error: string) => {
-        props.handleModelChange({ ...props.model, createError: error });
+        props.handleModelChange({
+          ...props.model,
+          createError: error,
+          createInProgress: false
+        });
       });
   };
 
@@ -683,6 +733,13 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
   const cantSubmit = trans.__('One or more of the fields has an error.');
   const createError: string | undefined = props.model.createError;
 
+  const homeAdornment = (
+    <InputAdornment position="start">
+      <FolderIcon fontSize="small" />
+      &nbsp;&nbsp;/
+    </InputAdornment>
+  );
+
   return (
     <Box sx={{ p: 4 }}>
       <form className={`${formPrefix}form`} onSubmit={e => e.preventDefault()}>
@@ -706,17 +763,10 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
             helperText={errors['inputFile'] ?? ''}
             name="inputFile"
             InputProps={{
-              readOnly: true
+              readOnly: true,
+              startAdornment: homeAdornment
             }}
           />
-          <TextField
-            label={trans.__('Output path')}
-            variant="outlined"
-            onChange={handleInputChange}
-            value={props.model.outputPath}
-            id={`${formPrefix}outputPath`}
-            name="outputPath"
-          />
           <EnvironmentPicker
             label={trans.__('Environment')}
             name={'environment'}
@@ -800,20 +850,36 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
             handleErrorsChange={setErrors}
           />
           <Cluster gap={3} justifyContent="flex-end">
-            <Button variant="outlined" onClick={e => props.showListView('Job')}>
-              {trans.__('Cancel')}
-            </Button>
-            <Button
-              variant="contained"
-              onClick={(e: React.MouseEvent) => {
-                submitForm(e);
-                return false;
-              }}
-              disabled={anyErrors}
-              title={anyErrors ? cantSubmit : ''}
-            >
-              {trans.__('Create')}
-            </Button>
+            {props.model.createInProgress || (
+              <>
+                <Button
+                  variant="outlined"
+                  onClick={e => props.showListView('Job')}
+                >
+                  {trans.__('Cancel')}
+                </Button>
+
+                <Button
+                  variant="contained"
+                  onClick={(e: React.MouseEvent) => {
+                    submitForm(e);
+                    return false;
+                  }}
+                  disabled={anyErrors}
+                  title={anyErrors ? cantSubmit : ''}
+                >
+                  {trans.__('Create')}
+                </Button>
+              </>
+            )}
+            {props.model.createInProgress && (
+              <>
+                {props.model.createType === 'Job'
+                  ? trans.__('Creating job …')
+                  : trans.__('Creating job definition …')}
+                <CircularProgress size="30px" />
+              </>
+            )}
           </Cluster>
         </Stack>
       </form>
