@@ -33,6 +33,8 @@ export interface IDetailViewProps {
   setCreateJobModel: (createModel: ICreateJobModel) => void;
   setJobsView: (view: JobsView) => void;
   setListJobsView: (view: ListJobsView) => void;
+  showJobDetail: (jobId: string) => void;
+  showCreateJob: (state: ICreateJobModel) => void;
   // Extension point: optional additional component
   advancedOptions: React.FunctionComponent<Scheduler.IAdvancedOptionsProps>;
 }
@@ -55,9 +57,6 @@ export function DetailView(props: IDetailViewProps): JSX.Element {
   const [jobModel, setJobsModel] = useState<IJobDetailModel | null>(null);
   const [jobDefinitionModel, setJobDefinitionModel] =
     useState<IJobDefinitionModel | null>(null);
-  const [outputFormatStrings, setOutputFormatStrings] = useState<
-    string[] | null
-  >(null);
 
   const trans = useTranslator('jupyterlab');
 
@@ -65,7 +64,6 @@ export function DetailView(props: IDetailViewProps): JSX.Element {
 
   const fetchJobDetailModel = async () => {
     const jobFromService = await ss.getJob(props.model.id);
-    setOutputFormatStrings(jobFromService.output_formats ?? []);
     const jobDetailModel = convertDescribeJobtoJobDetail(jobFromService);
     setJobsModel(jobDetailModel);
   };
@@ -87,7 +85,7 @@ export function DetailView(props: IDetailViewProps): JSX.Element {
         fetchJobDefinitionModel();
         break;
     }
-  }, [props.model]);
+  }, [props.model, props.model.detailType, props.model.id]);
 
   const BreadcrumbsStyled = (
     <div role="presentation">
@@ -133,21 +131,25 @@ export function DetailView(props: IDetailViewProps): JSX.Element {
             <JobDetail
               app={props.app}
               model={jobModel}
-              handleModelChange={() => fetchJobDetailModel()}
+              handleModelChange={fetchJobDetailModel}
               setCreateJobModel={props.setCreateJobModel}
               setJobsView={props.setJobsView}
               setListJobsView={props.setListJobsView}
               // Extension point: optional additional component
               advancedOptions={props.advancedOptions}
-              outputFormatsStrings={outputFormatStrings ?? []}
             />
           )}
           {props.model.detailType === 'JobDefinition' && jobDefinitionModel && (
             <JobDefinition
+              app={props.app}
               model={jobDefinitionModel}
               setJobsView={props.setJobsView}
               setListJobsView={props.setListJobsView}
               refresh={fetchJobDefinitionModel}
+              showCreateJob={props.showCreateJob}
+              showJobDetail={props.showJobDetail}
+              // Extension point: optional additional component
+              advancedOptions={props.advancedOptions}
             />
           )}
           {!jobModel && !jobDefinitionModel && (
